@@ -24,11 +24,9 @@ import logging
 import platform
 import subprocess
 import os
-from os.path import join
 import pexpect
 from tests.large import LargeFrameworkTests
 from tests.tools import UMAKE
-from umake.frameworks.ide import Idea, PyCharm, PyCharmEducational, PyCharmProfessional, PhpStorm, RubyMine, WebStorm
 
 logger = logging.getLogger(__name__)
 
@@ -44,15 +42,6 @@ class EclipseIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/eclipse")
         self.desktop_filename = "eclipse.desktop"
-        self.icon_filename = "icon.xpm"
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "eclipse")
 
     @property
     def arch_option(self):
@@ -69,8 +58,8 @@ class EclipseIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -103,15 +92,6 @@ class IdeaIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/idea")
         self.desktop_filename = 'jetbrains-idea.desktop'
-        self.icon_filename = 'idea.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", Idea.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -123,8 +103,8 @@ class IdeaIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -151,15 +131,6 @@ class IdeaUltimateIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/idea-ultimate")
         self.desktop_filename = 'jetbrains-idea.desktop'
-        self.icon_filename = 'idea.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", Idea.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -173,8 +144,8 @@ class IdeaUltimateIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -201,15 +172,6 @@ class PyCharmIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/pycharm")
         self.desktop_filename = 'jetbrains-pycharm.desktop'
-        self.icon_filename = 'pycharm.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", PyCharm.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -223,8 +185,8 @@ class PyCharmIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -251,15 +213,6 @@ class PyCharmEducationalIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/pycharm-educational")
         self.desktop_filename = 'jetbrains-pycharm.desktop'
-        self.icon_filename = 'pycharm.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", PyCharmEducational.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -273,8 +226,8 @@ class PyCharmEducationalIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -301,15 +254,6 @@ class PyCharmProfessionalIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/pycharm-professional")
         self.desktop_filename = 'jetbrains-pycharm.desktop'
-        self.icon_filename = 'pycharm.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", PyCharmProfessional.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -323,8 +267,8 @@ class PyCharmProfessionalIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -351,15 +295,6 @@ class RubyMineIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/rubymine")
         self.desktop_filename = 'jetbrains-rubymine.desktop'
-        self.icon_filename = 'rubymine.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", RubyMine.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -373,8 +308,8 @@ class RubyMineIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -401,15 +336,6 @@ class WebStormIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/webstorm")
         self.desktop_filename = 'jetbrains-webstorm.desktop'
-        self.icon_filename = 'webide.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", WebStorm.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -423,8 +349,8 @@ class WebStormIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -451,15 +377,6 @@ class PhpStormIDETests(LargeFrameworkTests):
         super().setUp()
         self.installed_path = os.path.expanduser("~/tools/ide/phpstorm")
         self.desktop_filename = 'jetbrains-phpstorm.desktop'
-        self.icon_filename = 'webide.png'
-
-    @property
-    def full_icon_path(self):
-        return join(self.installed_path, 'bin', self.icon_filename)
-
-    @property
-    def exec_path(self):
-        return join(self.installed_path, "bin", PhpStorm.executable)
 
     def test_default_install(self):
         """Install from scratch test case"""
@@ -473,8 +390,8 @@ class PhpStormIDETests(LargeFrameworkTests):
 
         # we have an installed launcher, added to the launcher and an icon file
         self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
-        self.assertTrue(self.path_exists(self.exec_path))
-        self.assertTrue(self.path_exists(self.full_icon_path))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
 
         # launch it, send SIGTERM and check that it exits fine
         proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
@@ -488,3 +405,48 @@ class PhpStormIDETests(LargeFrameworkTests):
         self.expect_and_no_warn("PhpStorm is already installed.*\[.*\] ")
         self.child.sendline()
         self.wait_and_no_warn()
+
+
+class ArduinoIDETests(LargeFrameworkTests):
+    """The Arduino Software distribution from the IDE collection."""
+
+    TIMEOUT_INSTALL_PROGRESS = 120
+    TIMEOUT_START = 60
+    TIMEOUT_STOP = 60
+
+    def setUp(self):
+        super().setUp()
+        self.installed_path = os.path.expanduser("~/tools/ide/arduino")
+        self.desktop_filename = "arduino.desktop"
+
+    @property
+    def arch_option(self):
+        """we return the expected arch call on command line"""
+        return platform.machine()
+
+    def test_default_install(self):
+        """Install the distribution from scratch test case"""
+        self.child = pexpect.spawnu(self.command('{} ide arduino'.format(UMAKE)))
+        self.expect_and_no_warn("Choose installation path: {}".format(self.installed_path))
+        self.child.sendline("")
+        self.expect_and_no_warn("Installation done", timeout=self.TIMEOUT_INSTALL_PROGRESS)
+        self.wait_and_no_warn()
+
+        # we have an installed launcher, added to the launcher and an icon file
+        self.assertTrue(self.launcher_exists_and_is_pinned(self.desktop_filename))
+        self.assert_exec_exists()
+        self.assert_icon_exists()
+        self.assertTrue(self.is_in_group("dialout"))
+
+        # launch it, send SIGTERM and check that it exits fine
+        proc = subprocess.Popen(self.command_as_list(self.exec_path), stdout=subprocess.DEVNULL,
+                                stderr=subprocess.DEVNULL)
+
+        self.check_and_kill_process(["java", "processing.app.Base"], wait_before=self.TIMEOUT_START)
+        proc.wait(self.TIMEOUT_STOP)
+
+        # ensure that it's detected as installed:
+        self.child = pexpect.spawnu(self.command('{} ide arduino'.format(UMAKE)))
+        self.expect_and_no_warn("Arduino is already installed.*\[.*\] ")
+        self.child.sendline()
+        self.wait_and_no_warn()
