@@ -20,15 +20,22 @@
 
 
 """Generic IDE module."""
-
-from gettext import gettext as _
-import logging
-import platform
-from bs4 import BeautifulSoup
 from abc import ABCMeta, abstractmethod
-
+from bs4 import BeautifulSoup
+from concurrent import futures
+from gettext import gettext as _
+import grp
+import logging
+import os
 from os.path import join, isfile
+import pwd
+import platform
+import re
+import subprocess
+from urllib import parse
+
 import umake.frameworks.baseinstaller
+from umake.interactions import DisplayMessage
 from umake.network.download_center import DownloadCenter, DownloadItem
 from umake.tools import create_launcher, get_application_desktop_file, ChecksumType, Checksum, MainLoop
 from umake.ui import UI
@@ -37,6 +44,20 @@ from umake.ui import UI
 logger = logging.getLogger(__name__)
 
 
+def _add_to_group(user, group):
+        """Add user to group. Should only be used in an other process"""
+        # switch to root
+        os.seteuid(0)
+        os.setegid(0)
+        try:
+            output = subprocess.check_output(["adduser", user, group])
+            logger.debug("Added {} to {}: {}".format(user, group, output))
+            return True
+        except subprocess.CalledProcessError as e:
+            logger.error("Couldn't add {} to {}".format(user, group))
+            return False
+
+
 class IdeCategory(umake.frameworks.BaseCategory):
     def __init__(self):
         super().__init__(name="IDE", description=_("Generic IDEs"),
@@ -75,13 +96,13 @@ class Eclipse(umake.frameworks.baseinstaller.BaseInstaller):
             logger.error("Unsupported architecture: {}".format(arch))
             UI.return_main_screen()
 
+        @MainLoop.in_mainloop_thread
         def done(download_result):
             res = download_result[md5_url]
 
             if res.error:
                 logger.error(res.error)
                 UI.return_main_screen()
-                return
 
             # Should be ASCII anyway.
             md5 = res.buffer.getvalue().decode('utf-8').split()[0]
@@ -162,7 +183,6 @@ class BaseJetBrains(umake.frameworks.baseinstaller.BaseInstaller, metaclass=ABCM
             if checksum_result.error:
                 logger.error(checksum_result.error)
                 UI.return_main_screen()
-                return
 
             checksum = checksum_result.buffer.getvalue().decode('utf-8').split()[0]
             logger.info('Obtained SHA256 checksum: ' + checksum)
@@ -327,3 +347,129 @@ class PhpStorm(BaseJetBrains):
                          desktop_filename='jetbrains-phpstorm.desktop',
                          packages_requirements=['openjdk-7-jdk', 'jayatana'],
                          icon_filename='webide.png')
+
+
+class Arduino(umake.frameworks.baseinstaller.BaseInstaller):
+    """The Arduino Software distribution."""
+
+    ARDUINO_GROUP = "dialout"
+
+    def __init__(self, category):
+
+        if os.geteuid() != 0:
+            self._current_user = os.getenv("USER")
+        self._current_user = pwd.getpwuid(int(os.getenv("SUDO_UID", default=0))).pw_name
+        for group_name in [g.gr_name for g in grp.getgrall() if self._current_user in g.gr_mem]:
+            if group_name == self.ARDUINO_GROUP:
+                self.was_in_arduino_group = True
+                break
+        else:
+            self.was_in_arduino_group = False
+
+        super().__init__(name="Arduino",
+                         description=_("The Arduino Software Distribution"),
+                         category=category, only_on_archs=['i386', 'amd64'],
+                         download_page='http://www.arduino.cc/en/Main/Software',
+                         dir_to_decompress_in_tarball='arduino-*',
+                         desktop_filename='arduino.desktop',
+                         packages_requirements=['openjdk-7-jdk', 'jayatana', 'gcc-avr', 'avr-libc'],
+                         need_root_access=not self.was_in_arduino_group)
+        self.scraped_checksum_url = None
+        self.scraped_download_url = None
+
+        # This is needed later in several places.
+        # The framework covers other cases, in combination with self.only_on_archs
+        self.bits = '32' if platform.machine() == 'i686' else '64'
+
+    @MainLoop.in_mainloop_thread
+    def get_metadata_and_check_license(self, result):
+        """We diverge from the BaseInstaller implementation a little here."""
+        logger.debug("Parse download metadata")
+
+        error_msg = result[self.download_page].error
+        if error_msg:
+            logger.error("An error occurred while downloading {}: {}".format(self.download_page, error_msg))
+            UI.return_main_screen()
+
+        soup = BeautifulSoup(result[self.download_page].buffer)
+
+        # We need to avoid matching arduino-nightly-...
+        download_link_pat = r'arduino-(\d\.?){1,3}-linux' + self.bits + '.tar.xz$'
+
+        self.scraped_download_url = soup.find('a', href=re.compile(download_link_pat))['href']
+        self.scraped_checksum_url = soup.find('a', text=re.compile('Checksums'))['href']
+
+        self.scraped_download_url = 'http:' + self.scraped_download_url
+        self.scraped_checksum_url = 'http:' + self.scraped_checksum_url
+
+        if not self.scraped_download_url:
+            logger.error("Can't parse the download link from %s.", self.download_page)
+            UI.return_main_screen()
+        if not self.scraped_checksum_url:
+            logger.error("Can't parse the checksum link from %s.", self.download_page)
+            UI.return_main_screen()
+
+        DownloadCenter([DownloadItem(self.scraped_download_url), DownloadItem(self.scraped_checksum_url)],
+                       on_done=self.prepare_to_download_archive, download=False)
+
+    @MainLoop.in_mainloop_thread
+    def prepare_to_download_archive(self, results):
+        """Store the md5 for later and fire off the actual download."""
+        download_page = results[self.scraped_download_url]
+        checksum_page = results[self.scraped_checksum_url]
+        if download_page.error:
+            logger.error("Error fetching download page: %s", download_page.error)
+            UI.return_main_screen()
+        if checksum_page.error:
+            logger.error("Error fetching checksums: %s", checksum_page.error)
+            UI.return_main_screen()
+
+        match = re.search(r'^(\S+)\s+arduino-(\d\.?){1,3}-linux' + self.bits + '.tar.xz$',
+                          checksum_page.buffer.getvalue().decode('ascii'),
+                          re.M)
+        if not match:
+            logger.error("Can't parse the checksum.")
+            UI.return_main_screen()
+        checksum = match.group(1)
+
+        soup = BeautifulSoup(download_page.buffer.getvalue())
+        btn = soup.find('button', text=re.compile('JUST DOWNLOAD'))
+
+        if not btn:
+            logger.error("Can't parse download button.")
+            UI.return_main_screen()
+
+        base_url = download_page.final_url
+        cookies = download_page.cookies
+
+        final_download_url = parse.urljoin(base_url, btn.parent['href'])
+
+        logger.info('Final download url: %s, cookies: %s.', final_download_url, cookies)
+
+        self.download_requests = [DownloadItem(final_download_url,
+                                               checksum=Checksum(ChecksumType.md5, checksum),
+                                               cookies=cookies)]
+
+        # add the user to arduino group
+        if not self.was_in_arduino_group:
+            with futures.ProcessPoolExecutor(max_workers=1) as executor:
+                f = executor.submit(_add_to_group, self._current_user, self.ARDUINO_GROUP)
+                if not f.result():
+                    UI.return_main_screen()
+
+        self.start_download_and_install()
+
+    def post_install(self):
+        """Create the Luna launcher"""
+        icon_path = join(self.install_path, 'lib', 'arduino_icon.ico')
+        exec_path = '"{}" %f'.format(join(self.install_path, "arduino"))
+        comment = _("The Arduino Software IDE")
+        categories = "Development;IDE;"
+        create_launcher(self.desktop_filename,
+                        get_application_desktop_file(name=_("Arduino"),
+                                                     icon_path=icon_path,
+                                                     exec=exec_path,
+                                                     comment=comment,
+                                                     categories=categories))
+        if not self.was_in_arduino_group:
+            UI.delayed_display(DisplayMessage(_("You need to logout and login again for your installation to work")))
